Coverage for tests/test_manage.py: 100%

# Coverage for tests/test_manage.py : 100%

## 8 statements

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 import os

2 import sys

3 import subprocess

4

5 import pytest

6

7

8 def test_managepy(capfd):

9 subprocess.run([sys.executable, "manage.py", "testok"], text=True)

10 captured = capfd.readouterr()

11 assert "test ok!" in captured.out